@@ -55,7 +55,7 @@ int DummyModel::count() const
 
 QHash<QByteArray, QVariant> DummyModel::data(int index) const
 {
-    Q_UNUSED(index);
+    Q_UNUSED(index)
     return QHash<QByteArray, QVariant>();
 }
 
